@rem = ' This is a perl script for NT and UNIX.
@echo off
goto endofperl
@rem ';
# -*- tab-width: 4 -*-

#
# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 2003, 2005. All Rights Reserved
# US Government Users Restricted Rights
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with 
# IBM Corp
#
# cc_generate_family_health.bat
# usage: cc_generate_family_health [-window hours] vob-tag...
# 
# This script is intended to be run periodically by the ClearCase
# Job Scheduler to collect family health data for a VOB that resides
# on the local host.  
#
# It is not intended to be run interactively.
#

use strict;
use Getopt::Long;

my $thisscript = $0;
if ($thisscript =~ m/(.*)(\.bat)$/) {
    $thisscript = $1;
}

$CFG::including_script = $thisscript;

my $pkg_name = 'cc_generate_family_health';

use Config;

my $arch = $^O ? $^O : $main::Config{archname};
$CFG::NT = (($arch =~ /^MSWin32/) || ($arch eq 'i386-win32')) ? 1 : 0;
$CFG::UNIX = ($CFG::NT ? 0 : 1);

# CLEARCASEHOME e.v. should always be set on NT when called by ccperlpp.pl,
# so exit if it's not set. On UNIX, assume /opt/rational/clearcase if user
# hasn't explicitly set CLEARCASEHOME (or deprecated ATRIAHOME).
#
if ($CFG::UNIX) {
    if (!exists $ENV{CLEARCASEHOME}) {
        # check for (now deprecated) ATRIAHOME e.v.; use if set.
        if (exists $ENV{ATRIAHOME} ) {
            $ENV{CLEARCASEHOME} = $ENV{ATRIAHOME};
        } else {
            $ENV{CLEARCASEHOME} = "/opt/rational/clearcase";
        }
    }
    my $producthome = $ENV{CLEARCASEHOME};

    chdir $producthome;
    push(@INC, "$producthome/config/scheduler/tasks");
} else {
    my $producthome = $ENV{CLEARCASEHOME} or 
                      die "CLEARCASEHOME environment variable not set\n";
    chdir $producthome;
    push(@INC, "$producthome\\config\\scheduler\\tasks");
    $thisscript = $pkg_name;
}

# set script version to test for mismatch against the syncmgr_common.pl version.
$CFG::MS_script_version = "7.0.0.0_syncmgr";

require 'syncmgr_common.pl';
require 5.8.6;

if (!$CFG::MScommon_version) {
    $CFG::MScommon_version = "(unknown older version)";
}

# check for mismatched versions - syncmgr_common.pl should set 
# $CFG::MScommon_version; if not set or unequal, may indicate that an 
# older/newer version is being included improperly.

if ($CFG::MScommon_version ne $CFG::MS_script_version) {
    die "Version mismatch between require file 'syncmgr_common.pl' " .
        "(version: ${CFG::MScommon_version}) and \n" .
        "the MultiSite family health script which includes it, " .
        "'cc_generate_family_health.bat' " . 
        "(version: ${CFG::MS_script_version}).\n" . 
        "Ensure that old versions of the script/require file are not in use.\n";
}

my $usage = "Usage: $thisscript [-window hours] vob_tag...\n";
my $window = 0;
my $help;
my $st = GetOptions("window=i" => \$window,
                    "help!" => \$help);

if ($help) {
    die $usage;
}

my $num_tags = scalar(@ARGV);

# bad usage if no args left or GetOptions failed
if (!$st || $num_tags == 0) { 
    die "ERROR: error getting command line options.\n" . $usage;
}

my $cmd = $CFG::MultiTool . " familysyncstatus -generate ";

if ($window) {
    $cmd .= "-sync_window $window ";
} 

# treat all remaining elements of @ARGV as vob tags to be used in a single
# generate command
$cmd .= join(' ', @ARGV);

my $res = Do_System("$cmd", __FILE__, __LINE__); 
if ($res) {
    my $msg = "ERROR: error executing \"$cmd\"\n";
    print STDERR $msg;	
    exit 1;
} 

__END__
:endofperl
ccperl -S ccperlpp.pl %0.bat %*
